@@ -48,6 +48,13 @@ class Dataset(LoadsDatasetMixin, PlotsItselfMixin):
         """
         return self.replace(X=self.X[item, :], y=self.y[item], columns=self.columns)
 
+    def __len__(self):
+        """
+        Get length of dataset
+        :return: int
+        """
+        return self.length
+
     @property
     def y_categorical(self):
         """
@@ -199,6 +206,16 @@ class Dataset(LoadsDatasetMixin, PlotsItselfMixin):
 
         return Dataset(name=name, X=X.copy(), y=y.copy(), columns=columns, classmap=self.classmap)
 
+    def select_columns(self, columns):
+        """
+        Only keep given columns
+        :return: Dataset
+        """
+        column_indices = [i for i, column in enumerate(self.columns) if column in columns]
+        X = self.X[:, column_indices]
+
+        return self.replace(X=X, columns=columns)
+
     def shuffle(self, **kwargs):
         """
         Shuffle X and y
@@ -477,6 +494,16 @@ class Dataset(LoadsDatasetMixin, PlotsItselfMixin):
 
         self.y = y
 
+    def sort_by_class(self):
+        """
+        Sort samples by class.
+        Useful if you have mixed samples and want to "compact" the samples from the same class.
+        This will lose the "transient" dynamics, but should help improve the precision
+        """
+        indices = np.argsort(self.y)
+
+        return self.replace(X=self.X[indices], y=self.y[indices])
+
     def _get_label_id(self, label):
         """
         Get id for a label
