@@ -1,4 +1,5 @@
 import re
+import numpy as np
 from eloquentarduino.ml.data.preprocessing.pipeline.BaseStep import BaseStep
 from eloquentarduino.ml.classification.abstract.Classifier import Classifier
 
@@ -31,6 +32,10 @@ class Classify(BaseStep):
         """
         y_pred = self.clf.predict(X)
 
+        # reshape NN predictions (N x M) to 1d array
+        if len(y_pred.shape) > 1 and y_pred.shape[1] > 1:
+            y_pred = np.argmax(y_pred, axis=1)
+
         return y_pred.reshape((-1, 1)), y
 
     def get_template_data(self):
@@ -48,4 +53,12 @@ class Classify(BaseStep):
         # drop duplicated `#pragma once`
         ported = re.sub(r'(#pragma once[\s\S]+)#pragma once', lambda g: g.group(1), ported)
 
-        return ported
\ No newline at end of file
+        return ported
+
+    def get_config(self):
+        """
+        Show details of classifier
+        """
+        return {
+            'clf': self.clf
+        }
\ No newline at end of file
